/*:
## **Aufgabe DorianLand – Level 3**
*/

/**
Ein rechteckiges Objekt im Dorianland mit vier unsichtbaren Begrenzungen:
- linker Rand durch eine schwarze Linie
- rechter Rand durch eine weiße Linie
- oberer Rand durch eine hellgrüne Linie
- unterer Rand durch eine hellgelbe Linie

- author: Johannes Neumeyer
- version: 1.0
 */
class DLRechteck: Rechteck
{
    private var randLinks: Rechteck
    private var randRechts: Rechteck
    private var randOben: Rechteck
    private var randUnten: Rechteck
    private var koordinaten: Text

    /**
    Konstruktor für Objekte der Klasse DLRechteck
    */
    override init()
    {
        randLinks = Rechteck()
        randRechts = Rechteck()
        randOben = Rechteck()
        randUnten = Rechteck()
        koordinaten = Text()
        super.init()

        randLinks.PositionSetzen(x: x, y: y + 10)
        randLinks.GrößeSetzen(breite: 1, höhe: höhe - 10)
        randLinks.FarbeSetzen(farbe: "schwarz")

        randRechts.PositionSetzen(x: x + breite - 1, y: y + 10)
        randRechts.GrößeSetzen(breite: 1, höhe: höhe - 10)
        randRechts.FarbeSetzen(farbe: "weiß")

        randOben.PositionSetzen(x: x + 3, y: y)
        randOben.GrößeSetzen(breite: breite - 6, höhe: 10)
        randOben.FarbeSetzen(farbe: "hellgrün")
        
        randUnten.PositionSetzen(x: x + 3, y: y + höhe - 10)
        randUnten.GrößeSetzen(breite: breite - 6, höhe: 10)
        randUnten.FarbeSetzen(farbe: "hellgelb")

        randLinks.GanzNachHintenBringen()
        randRechts.GanzNachHintenBringen()
        randOben.GanzNachHintenBringen()
        randUnten.GanzNachHintenBringen()

        koordinaten.TextGrößeSetzen(größe: 10)
        KoordinatentextAktualisieren()
        koordinaten.PositionSetzen(x: x, y: y)
        koordinaten.FarbeSetzen(farbe: "schwarz")
        koordinaten.NachVornBringen()
    }

    /**
	Überschrieben, da auch die Positionen der unsichtbaren Ränder
	und der Koordinatentext aktualisiert werden müssen.
	- parameters:
		- x: die (neue) x-Koordinate
		- y: die (neue) y-Koordinate
    */
    override func PositionSetzen(x: Int, y: Int)
    {
        super.PositionSetzen(x: x, y: y);
        randLinks.PositionSetzen(x: x, y: y + 10);
        randRechts.PositionSetzen(x: x + breite - 1, y: y + 10);
        randOben.PositionSetzen(x: x + 3, y: y);
        randUnten.PositionSetzen(x: x + 3, y: y + höhe - 10);
        koordinaten.PositionSetzen(x: x, y: y);
        KoordinatentextAktualisieren();
    }

    /**
	Überschrieben, da auch die Größen/Positionen der unsichtbaren Ränder
	aktualisiert werden müssen.
	- parameters:
		- breite: die (neue) Breite
		- höhe: die (neue) Höhe
    */
    override func GrößeSetzen(breite: Int, höhe: Int)
    {
        super.GrößeSetzen(breite: breite, höhe: höhe)
        randLinks.GrößeSetzen(breite: randLinks.breite, höhe: höhe - 10)
        randRechts.GrößeSetzen(breite: randRechts.breite, höhe: höhe - 10)
        randRechts.PositionSetzen(x: x + breite - 1, y: y + 10)
        randOben.GrößeSetzen(breite: breite - 6, höhe: 10)
        randUnten.GrößeSetzen(breite: breite - 6, höhe: 10)
        randUnten.PositionSetzen(x: x + 3, y: y + höhe - 10)
    }

    /**
    Der Text, der die Koordinaten des Rechtecks angibt, wird aktualisiert.
    */
    private func KoordinatentextAktualisieren()
    {
        koordinaten.TextSetzen(text: "(\(x); \(y)")
    }
}

/**
Eine Kiste im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Kiste: DLRechteck
{
    private var brettLO: Rechteck
    private var brettLU: Rechteck

    // Größe der Kiste in 50er-Schritten (Kann die Werte 1, 2, 3, ... annehmen.)
    private var größe: Int
    private let faktor = 50
    private var breiteBrett: Int

    /**
    Standardkonstruktor
    */
    convenience override init()
    {
        self.init(größe: 1)
    }

    /**
    Konstruktor mit Größenangabe
	- parameters:
		- größe: Größe der Kiste
    */
    init(größe: Int)
    {
        breiteBrett = faktor / 10
        self.größe = größe
        brettLO = Rechteck()
        brettLU = Rechteck()
        super.init()
        brettLO.GanzNachVornBringen()
        brettLU.GanzNachVornBringen()
        KisteAnlegen()
    }

    /**
    Legt die Kiste an.
    */
    private func KisteAnlegen()
    {
        GrößeSetzen(breite: größe * faktor, höhe: größe * faktor)
        FarbeSetzen(farbe: "braun")

        brettLO.FarbeSetzen(farbe: "schwarz")
        brettLO.GrößeSetzen(breite: breiteBrett, höhe: größe * faktor)
        brettLO.PositionSetzen(x: x + (größe * faktor) / 2 - breiteBrett / 2, y: y)
        brettLO.WinkelSetzen(winkel: 45)

        brettLU.FarbeSetzen(farbe: "schwarz")
        brettLU.PositionSetzen(x: x + (größe * faktor) / 2 - breiteBrett / 2, y: y)
        brettLU.GrößeSetzen(breite: breiteBrett, höhe: größe * faktor)
        brettLU.WinkelSetzen(winkel: 135)
    }

    /**
    Setzt die Position aller Komponenten der Kiste.
	- parameters:
		- x: die (neue) x-Koordinate
		- y: die (neue) y-Koordinate
    */
    override func PositionSetzen(x: Int, y: Int)
    {
        super.PositionSetzen(x: x, y: y)
        brettLO.PositionSetzen(x: x + (größe * faktor) / 2 - breiteBrett / 2, y: y)
        brettLU.PositionSetzen(x: x + (größe * faktor) / 2 - breiteBrett / 2, y: y)
    }

    /**
    Gibt die Höhe der Kiste zurück.
	- returns: Höhe der Kiste
    */
    func HöheGeben() -> Int
    {
        return höhe
    }
}

/**
 Ziel eines Levels im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Ziel: DLRechteck
{
    /**
    Standardkonstruktor
    */
    override init()
    {
        super.init()
        GrößeSetzen(breite: 50, höhe: 10)
        FarbeSetzen(farbe: "cyan")
    }
}

/**
Ein Stahlträger im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Stahlträger: DLRechteck
{
    /**
    Standardkonstruktor
    */
    override init()
    {
        super.init()
        GrößeSetzen(breite: 200, höhe: 25)
        FarbeSetzen(farbe: "grau")
    }

    /**
    Konstruktor mit Breitenangabe
    - parameters:
    	- breite: Breite des Stahlträgers
	*/
    init(breite:Int)
    {
        super.init()
        GrößeSetzen(breite: breite, höhe: 25)
        FarbeSetzen(farbe: "grau")
    }
}

/**
Stufe einer Treppe im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Stufe: DLRechteck
{

    private var yPos: Int
    
    /**
    Konstruktor mit Höhenangabe
	- parameters:
		- höhe: Stufenhöhe
    */
    init(höhe: Int)
    {
        yPos = 400 - 25 * höhe
        super.init()
        GrößeSetzen(breite: 25, höhe: 25 * höhe)
        FarbeSetzen(farbe: "blau")
    }

    /**
    Positioniert die Stufe in x-Richtung
	- parameters:
		- xNeu: (neue) x-Position
    */
    func XPositionSetzen(xNeu: Int)
    {
        PositionSetzen(x: xNeu, y: yPos)
    }
}

/**
Gefährliches gleitendes Tier im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Gleiter: Figur
{
    private var richtung: Character

    /**
    Standardkonstruktor
    */
    override init()
    {
        richtung = "r"
        super.init()
        FigurFestlegen()
    }

    /**
    Steuert die Bewegungen des Gleiters.
    */
    override func AktionAusführen()
    {
        // Fallen
        if !Berührt(farbe: "grau")
        {
            while !Berührt(farbe: "grau") && YPositionGeben() < 600
            {
                PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
            }
        }

        // Hin- und Herkrabbeln
        else
        {
            if richtung == "r"
            {
                if !Berührt(farbe: "schwarz")
                {
                    PositionSetzen(x: XPositionGeben() + 1, y: YPositionGeben())
                }
                else
                {
                    richtung = "l"
                }
            }
            else
            {
                if !Berührt(farbe: "weiß")
                {
                    PositionSetzen(x: XPositionGeben() - 1, y: YPositionGeben())
                }
                else
                {
                    richtung = "r"
                }
            }
        }
    }

    /**
    Legt das Aussehen des Gleiters fest.
    */
    private func FigurFestlegen()
    {
        FigurteilFestlegenEllipse(x: -40, y: -50, breite: 80, höhe: 50, farbe: "grün")
        FigurteilFestlegenEllipse(x: -15, y: -30, breite: 10, höhe: 10, farbe: "rot")
        FigurteilFestlegenEllipse(x: 5, y: -30, breite: 10, höhe: 10, farbe: "rot")
        FigurteilFestlegenDreieck(x1: -20, y1: -35, x2: -10, y2: -30, x3: -5, y3: -35, farbe: "rot")
        FigurteilFestlegenDreieck(x1: 20, y1: -35, x2: 10, y2: -30, x3: 5, y3: -35, farbe: "rot")
        FigurteilFestlegenRechteck(x: -20, y: -15, breite: 40, höhe: 5, farbe: "rot")
    }
}

/**
Gefährliches springendes Untier im Dorianland

- author: Johannes Neumeyer
- version: 1.0
*/
class Springer: Figur
{
    private var sprung: Bool
    private var sprungzähler: Int
    private var teilsprungzähler: Int

    /**
    Standardkonstruktor
    */
    override init()
    {
        sprung = false
        sprungzähler = 0
        teilsprungzähler = 0
        super.init()
        FigurFestlegen()
    }

    /**
    Steuert das Springen und Fallen des Springers.
    */
    override func AktionAusführen()
    {
        // wenn er den Boden berührt --> nach oben abspringen
        if Berührt(farbe: "grau")
        {
            sprungzähler = 20
            sprung = true
            Teilsprung()
        }

        // wenn er den Boden nicht berührt und noch in der Sprungbewegung nach oben ist
        if !Berührt(farbe: "grau") && sprungzähler > 0
        {
            Teilsprung()
        }

        // Fallen
        if !(Berührt(farbe: "grau")) && YPositionGeben() < 600 && sprungzähler == 0
        {
            // Fallen nach dem Absprung
            if sprung
            {
                PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                if !Berührt(farbe: "grau") && YPositionGeben() < 600
                {
                    PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                }

            }
            // Fallen ohne vorangegangenen Absprung
            else
            {
                while !Berührt(farbe: "grau") && YPositionGeben() < 600 && sprungzähler == 0
                {
                    PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                }
            }

            if Berührt(farbe: "grau")
            {
                sprung = false;
            }
        }
    }

    /**
    Für die Steuerung beim Springen mitverantwortlich.
    */
    private func Teilsprung()
    {
        if teilsprungzähler <= 0
        {
            PositionSetzen(x: XPositionGeben(), y: YPositionGeben() - 10)
            sprungzähler = sprungzähler - 1
            teilsprungzähler = 5
        }
        else
        {
            teilsprungzähler = teilsprungzähler - 1
        }
    }

    /**
    Legt das Aussehen des Springers fest.
    */
    private func FigurFestlegen()
    {
        FigurteilFestlegenEllipse(x: -10, y: -50, breite: 20, höhe: 20, farbe: "grün")
        FigurteilFestlegenEllipse(x: -20, y: -30, breite: 40, höhe: 40, farbe: "grün")
        FigurteilFestlegenEllipse(x: -30, y: 10, breite: 60, höhe: 60, farbe: "grün")
        FigurteilFestlegenEllipse(x: -15, y: -30, breite: 10, höhe: 10, farbe: "rot")
        FigurteilFestlegenEllipse(x: 5, y: -30, breite: 10, höhe: 10, farbe: "rot")
        FigurteilFestlegenDreieck(x1: -20, y1: -35, x2: -10, y2: -30, x3: -5, y3: -35, farbe: "rot")
        FigurteilFestlegenDreieck(x1: 20, y1: -35, x2: 10, y2: -30, x3: 5, y3: -35, farbe: "rot")
        FigurteilFestlegenRechteck(x: -20, y: -15, breite: 40, höhe: 5, farbe: "rot")
    }
}

/**
Spielfigur Dorian

- author: Johannes Neumeyer
- version: 1.0
*/
class Dorian: Figur
{
    private var stop: Bool
    private var sprung: Bool
    private var sprungzähler: Int
    private var teilsprungzähler: Int

    /**
    Standardkonstruktor
    */
    override init()
    {
        stop = false
        sprung = false
        sprungzähler = 0
        teilsprungzähler = 0
        super.init()
        FigurFestlegen()
        PositionSetzen(x: 50, y: 100)
    }

    /**
	Leitet das Springen von Dorian ein.
	- parameters:
		- taste: die gedrückte Taste
    */
    override func TasteGedrückt (taste: Character)
    {
        switch taste
        {
          case " ":
            if !sprung
            {
                sprungzähler = 12
                teilsprungzähler = 5
                sprung = true
            }
          default:
        	break
        }
    }

    /**
	Steuert die Links- und Rechtsbewegung von Dorian.
	- parameters:
		- taste: die gedrückte Sondertaste
    */
    override func SonderTasteGedrückt (taste: Int)
    {
        if !stop
        {
            switch taste
            {
                // Pfeil rechts
              case 124:
                if !Berührt(farbe: "schwarz")
                {
                    PositionSetzen(x: XPositionGeben() + 4, y: YPositionGeben())
                }

                // Pfeil links
              case 123:
                if !Berührt(farbe: "weiß")
                {
                    PositionSetzen(x: XPositionGeben() - 4, y: YPositionGeben())
                }

                // Pfeil oben
              case 126:
                if !sprung
                {
                    sprungzähler = 12
                    teilsprungzähler = 5
                    sprung = true
                }
            default:
            	break
            }
        }
    }

    /**
    Steuert das Springen und Fallen von Dorian.
    */
    override func AktionAusführen()
    {
        // nach oben Springen
        if sprungzähler > 0
        {
            Teilsprung()
        }

        // Fallen
        if !(Berührt(farbe: "hellgrün")) && YPositionGeben() < 600 && sprungzähler == 0
        {
            // Fallen nach dem Absprung
            if sprung
            {
                PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                if (!Berührt(farbe: "hellgrün") && YPositionGeben() < 600)
                {
                    PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                }

            }
            // Fallen ohne vorangegangenen Absprung (senkrecht nach unten fallen)
            else
            {
                while !Berührt(farbe: "hellgrün") && YPositionGeben() < 600 && sprungzähler == 0
                {
                    PositionSetzen(x: XPositionGeben(), y: YPositionGeben() + 1)
                }
            }

            if Berührt(farbe: "hellgrün")
            {
                sprung = false
            }
        }
    }

    /**
    Prüft, ob Dorian beim Springen anstößt,
    und führt ansonsten die Sprungroutine weiter.
    */
    private func Teilsprung()
    {
        if teilsprungzähler <= 0
        {
            // Wenn Dorian mit dem Kopf an einem DLRechteck anstößt
            if Berührt(farbe: "hellgelb")
            {
                sprungzähler = 0
                teilsprungzähler = 0
            }
            else
            {
                PositionSetzen(x: XPositionGeben(), y: YPositionGeben() - 5)
                sprungzähler = sprungzähler - 1
                teilsprungzähler = 5
            }

        }
        else
        {
            teilsprungzähler = teilsprungzähler - 1
        }
    }

    /**
    Stoppt das Spiel, z. B. wenn Dorian das Ziel eines Levels erreicht hat
     */
    func Stoppen()
    {
        stop = true
    }

    /**
    Legt das Aussehen von Dorian fest.
    */
    private func FigurFestlegen()
    {
        GrößeSetzen(größe: 50);

        // Haare
        FigurteilFestlegenRechteck(x: -32, y: -50, breite: 30, höhe: 6, farbe: "rot");
        FigurteilFestlegenRechteck(x: -38, y: -44, breite: 48, höhe: 6, farbe: "rot");
 
        // Gesicht
        FigurteilFestlegenRechteck(x: -20, y: -38, breite: 24, höhe: 6, farbe: "orange");
        FigurteilFestlegenRechteck(x: -38, y: -32, breite: 48, höhe: 18, farbe: "orange");
        FigurteilFestlegenRechteck(x: -32, y: -14, breite: 40, höhe: 6, farbe: "orange");
        FigurteilFestlegenRechteck(x: 10, y: -26, breite: 6, höhe: 6, farbe: "orange");
 
        FigurteilFestlegenRechteck(x: -38, y: -38, breite: 18, höhe: 6, farbe: "rot");
        FigurteilFestlegenRechteck(x: -44, y: -32, breite: 6, höhe: 18, farbe: "rot");
        FigurteilFestlegenRechteck(x: -32, y: -32, breite: 6, höhe: 12, farbe: "rot");
        FigurteilFestlegenRechteck(x: -38, y: -20, breite: 6, höhe: 6, farbe: "rot");
        FigurteilFestlegenRechteck(x: -26, y: -26, breite: 6, höhe: 6, farbe: "rot");
 
        FigurteilFestlegenRechteck(x: -8, y: -38, breite: 6, höhe: 12, farbe: "schwarz");
        FigurteilFestlegenRechteck(x: -8, y: -20, breite: 18, höhe: 6, farbe: "schwarz");
 
        // blaues Hemd
        FigurteilFestlegenRechteck(x: -38, y: -8, breite: 48, höhe: 6, farbe: "blau");
        FigurteilFestlegenRechteck(x: -44, y: -2, breite: 60, höhe: 6, farbe: "blau");
        FigurteilFestlegenRechteck(x: -50, y: 4, breite: 72, höhe: 6, farbe: "blau");
        FigurteilFestlegenRechteck(x: -38, y: 10, breite: 6, höhe: 6, farbe: "blau");
        FigurteilFestlegenRechteck(x: 4, y: 10, breite: 6, höhe: 6, farbe: "blau");
 
        // Hände
        FigurteilFestlegenRechteck(x: -50, y: 10, breite: 12, höhe: 18, farbe: "orange");
        FigurteilFestlegenRechteck(x: -38, y: 16, breite: 6, höhe: 6, farbe: "orange");
        FigurteilFestlegenRechteck(x: 10, y: 10, breite: 12, höhe: 18, farbe: "orange");
        FigurteilFestlegenRechteck(x: 6, y: 16, breite: 6, höhe: 6, farbe: "orange");
 
        // braune Hose
        FigurteilFestlegenRechteck(x: -20, y: 10, breite: 12, höhe: 14, farbe: "braun");
        FigurteilFestlegenRechteck(x: -32, y: 10, breite: 12, höhe: 24, farbe: "braun");
        FigurteilFestlegenRechteck(x: -8, y: 10, breite: 12, höhe: 24, farbe: "braun");
        FigurteilFestlegenRechteck(x: -38, y: 22, breite: 6, höhe: 12, farbe: "braun");
        FigurteilFestlegenRechteck(x: 4, y: 22, breite: 6, höhe: 12, farbe: "braun");
 
        // Schuhe
        FigurteilFestlegenRechteck(x: -44, y: 34, breite: 18, höhe: 12, farbe: "grau");
        FigurteilFestlegenRechteck(x: -50, y: 40, breite: 6, höhe: 6, farbe: "grau");
        FigurteilFestlegenRechteck(x: -2, y: 34, breite: 18, höhe: 12, farbe: "grau");
        FigurteilFestlegenRechteck(x: 16, y: 40, breite: 6, höhe: 6, farbe: "grau");
    }
}

/**
Jump 'n' Run-Spiel mit dem Protagonisten Dorian

- author: Johannes Neumeyer
- version: 1.0
*/
class DorianLand: Ereignisbehandlung
{
    private let dorian: Dorian

    /**
	Legt das Szenorian und die Spielfigur an
	- parameters:
		- levelNr: das gewünschte Spiellevel
    */
    init(levelNr: Int)
    {
        dorian = Dorian()
        let text = Text()
        text.TextSetzen(text: "← →: Gehen     ↑ oder Leertaste: Springen")
        text.PositionSetzen(x: 300, y: 500)
        super.init()
        LevelSetzen(levelNr: levelNr)
        TaktdauerSetzen(dauer: 10)
        Starten()
    }

    /**
	Setzt das gewünschte Level.
	- parameters:
		- levelNr: das gewünschte Spiellevel
    */
    private func LevelSetzen(levelNr: Int)
    {
        switch levelNr
        {
          case 1:
            Level1()
          case 2:
            Level2()
          case 3:
            Level3()
          default:
            fatalError("Ein Level mit dieser Nummer existiert nicht!")
        }
    }

    /**
    Erstellt die Welt für Level 1.
    */
    private func Level1()
    {
        // Weg
        let weg = Stahlträger(breite: 800)
        weg.PositionSetzen(x: 0, y: 400)

        // Kisten und Untier
        let k1 = Kiste()
        k1.PositionSetzen(x: 250, y: 350)
        let k2 = Kiste()
        k2.PositionSetzen(x: 450, y: 350)
        let u1 = Gleiter()
        u1.PositionSetzen(x: 375, y: 375)

        // Ziel
        let ziel = Ziel()
        ziel.PositionSetzen(x: 735, y: 250)

        let st = Stahlträger()
        st.PositionSetzen(x: 275, y: 325)

        let k3 = Kiste()
        k3.PositionSetzen(x: 635, y: 350)

        let k4 = Kiste()
        k4.PositionSetzen(x: 685, y: 350)

        let k5 = Kiste()
        k5.PositionSetzen(x: 685, y: 300)
    }
    
    /**
    Erstellt die Welt für Level 2.
    */
    private func Level2()
    {
        // Weg oben
        let oben = Stahlträger(breite: 100)
        oben.PositionSetzen(x: 0, y: 150)
      
        // Weg unten
        let unten = Stahlträger(breite: 800)
        unten.PositionSetzen(x: 100, y: 400)

        // Ziel
        let ziel = Ziel()
        ziel.PositionSetzen(x: 735, y: 275)

        // Treppe1 bauen
        var treppe1 = [Stufe]()

        for index in 0 ..< 10
        {
            // Stufe erstellen und dem Feld hinzufügen
            treppe1.append(Stufe(höhe: 10 - index))
            // Stufe positionieren
            treppe1[index].XPositionSetzen(xNeu: 100 + index * 25)
        }

        // Treppe2 bauen
        var treppe2 = [Stufe]()

        for index in 0 ..< 5
        {
            treppe2.append(Stufe(höhe: index + 1))
            treppe2[index].XPositionSetzen(xNeu: 610 + index * 25)
        }

    }

    /**
    Erstellt die Welt für Level 3.
    */
    private func Level3()
    {
        let boden = Stahlträger(breite: 800)
        boden.PositionSetzen(x: 0, y: 400)

        let kRechts = Kiste()
        kRechts.PositionSetzen(x: 800, y: 350)

        var k: Kiste
        for zähler in 0 ..< 3
        {
            k = Kiste()
            k.PositionSetzen(x: 50 - (zähler % 2) * 10, y: 350 - zähler * 50)
            if zähler < 2
            {
                k = Kiste()
                k.PositionSetzen(x: 160 - (zähler % 2) * 10, y: 350 - zähler * 50)
            }
        }

        let s = Stahlträger(breite: 100)
        s.PositionSetzen(x: 50, y: 225)

        let g = Gleiter()
        g.PositionSetzen(x: 125, y: 350)

        // Ziel
        let ziel = Ziel()
        ziel.PositionSetzen(x: 735, y: 400)
        
        /*
        Hier müssen noch Untiere ergänzt werden.
        */
        
    }
    /**
    Mitverantwortlich für die Steuerung von Dorian
    */
    override func TaktImpulsAusführen()
    {
        if dorian.Berührt(farbe: "grün")
        {
            Anhalten()
            dorian.Stoppen()
        }

        else if dorian.Berührt(farbe: "cyan")
        {
            Anhalten()
            dorian.Stoppen()
        }
    }
}



DorianLand(levelNr: 3)
